#GLOVER ET AL. - BODY SIZE AS A MAGIC TRAIT IN TWO PLANT-FEEDING INSECT SPECIES
#MODELS AND FIGURES


#LOAD REQUIRED PACKAGES
library(car)
library(sjPlot)
library(sjmisc)
library(ggplot2)
library(MASS)
library(lme4)
library(emmeans)
library(lmerTest)
library(tidyverse)
library(dplyr)
library(ggtext)
library(cowplot)
library(performance)
library(patchwork)
library(scales)

#################################### MODELS/STATISTICAL TESTS

#### PINE NEEDLES

#read in the data
all_needles<-read.csv(file="pine_needle_width_latitude.csv",header=TRUE, na.strings="NA")
#make characters into factors
all_needles$host_species<-as.factor(all_needles$host_species)
all_needles$host_specialist<-as.factor(all_needles$host_specialist)

#how does needle width vary as a function of host species and latitude?
needles_model <- lm(data=all_needles, mean_needle_width~latitude*host_species)
summary(needles_model)
Anova(needles_model, type=3) 
emmeans(needles_model, pairwise~host_species, adjust="fdr")

#lecontei hosts latitudinal cline
lec_hosts <- subset(all_needles, all_needles$host_specialist=="LECONTEI")
lec_hosts_model <- lm(data=lec_hosts, mean_needle_width~latitude)
summary(lec_hosts_model)
Anova(lec_hosts_model, type=2) 

#pinetum hosts latitudinal cline
pine_hosts <- subset(all_needles, all_needles$host_specialist=="PINETUM")
pine_hosts_model <- lm(data=pine_hosts, mean_needle_width~latitude)
summary(pine_hosts_model)
Anova(pine_hosts_model, type=2)


#### BODY SIZE CLINES

#read in the data
combined_sizes<-read.csv(file="adult_female_male_body_sizes.csv",header=TRUE, na.strings="NA")

#make characters into factors
combined_sizes$species<-as.factor(combined_sizes$species)
combined_sizes$sex<-as.factor(combined_sizes$sex)

#body size cline model with all species/sexes combined
full_clinemodel<-lm(data=combined_sizes, body_length~latitude+species+sex+latitude*species+latitude*sex+species*sex)
summary(full_clinemodel)
Anova(full_clinemodel, type=3)
plot_model(full_clinemodel, type="int")

#body size cline models for each species/sex separately
#subset by sex then species
all_females <- subset(combined_sizes, combined_sizes$sex=="FEMALE")
lec_fems <- subset(all_females, all_females$species=="LECONTEI")
pine_fems <- subset(all_females, all_females$species=="PINETUM")
all_males <- subset(combined_sizes, combined_sizes$sex=="MALE")
lec_males <- subset(all_males, all_males$species=="LECONTEI")
pine_males <- subset(all_males, all_males$species=="PINETUM")
#lecontei females model
lec_fems_model <- lm(data=lec_fems, body_length~latitude)
summary(lec_fems_model)
Anova(lec_fems_model, type=2)
#lecontei males model
lec_males_model <- lm(data=lec_males, body_length~latitude)
summary(lec_males_model)
Anova(lec_males_model, type=2)
#pinetum females model
pine_fems_model <- lm(data=pine_fems, body_length~latitude)
summary(pine_fems_model)
Anova(pine_fems_model, type=2)
#pinetum males model
pine_males_model <- lm(data=pine_males, body_length~latitude)
summary(pine_males_model)
Anova(pine_males_model, type=2)


#### DIVERGENT SELECTION (EGG) MODELS

#Does egg size differ between N. lecontei and N. pinetum?

#read in the data
egg_size<-read.csv(file="egg_area_by_species.csv",header=TRUE, na.strings="NA")

#make characters into factors
egg_size$FemaleID<-as.factor(egg_size$FemaleID)
egg_size$Species<-as.factor(egg_size$Species)

#egg size differences model
egg_size_model <- lmer(data=egg_size, egg_area~Species+(1|FemaleID))
summary(egg_size_model)
Anova(egg_size_model, type=2) 
check_model(egg_size_model)

#Does egg size effect hatching success on different hosts?

#read in the data
hatch<-read.csv(file="backcross_female_eggsize_hatching.csv",header=TRUE, na.strings="NA")

#make characters into factors
hatch$Host<-as.factor(hatch$Host)

#hatching model
egg_hatch_model<-glm(data=hatch, PropHatch~egg_area+Host+Host*egg_area,weights=EggTotal,family=binomial)
summary(egg_hatch_model)
Anova(egg_hatch_model, type=3)
plot_model(egg_hatch_model, type="int")


#### ONE-SIDED FISHER'S EXACT TESTS (MATING OUTCOME DIFFERENT BETWEEN INTER- AND INTRA-SPECIFIC PAIRS?)

#CROSS 1

#read in the data
cross1<-read.csv(file="Cross1_size_mating_data.csv",header=TRUE,na.strings="NA")

#create data frame of 2x2 contingency table
library(stats)
length(which(cross1$Inter_or_intra == "INTRA" & cross1$mated_outcome == "0")) #57
length(which(cross1$Inter_or_intra == "INTRA" & cross1$mated_outcome == "1")) #15
length(which(cross1$Inter_or_intra == "INTER" & cross1$mated_outcome == "0")) #61
length(which(cross1$Inter_or_intra == "INTER" & cross1$mated_outcome == "1")) #11
cross1exact <- data.frame("mated" = c(15,11), "unmated" = c(57,61), row.names = c("INTRA","INTER"))
cross1exact
mosaicplot(cross1exact,color=TRUE)

#perform Fisher's exact tests
fisher.test(cross1exact,alternative="greater") 

#CROSS 2

#read in the data
cross2<-read.csv(file="Cross2_size_mating_data.csv",header=TRUE,na.strings="NA")

#create data frame of 2x2 contingency table
library(stats)
length(which(cross2$Inter_or_intra == "INTRA" & cross2$mated_outcome == "0")) #17
length(which(cross2$Inter_or_intra == "INTRA" & cross2$mated_outcome == "1")) #13
length(which(cross2$Inter_or_intra == "INTER" & cross2$mated_outcome == "0")) #24
length(which(cross2$Inter_or_intra == "INTER" & cross2$mated_outcome == "1")) #6
cross2exact <- data.frame("mated" = c(13,6), "unmated" = c(17,24), row.names = c("INTRA","INTER"))
cross2exact
mosaicplot(cross2exact,color=TRUE)

#perform Fisher's exact tests
fisher.test(cross2exact,alternative="greater") 

#CROSS 3

#read in the data
cross3<-read.csv(file="Cross3_size_mating_data.csv",header=TRUE,na.strings="NA")

#create data frame of 2x2 contingency table
library(stats)
length(which(cross3$Inter_or_intra == "INTRA" & cross3$mated_outcome == "0")) #15
length(which(cross3$Inter_or_intra == "INTRA" & cross3$mated_outcome == "1")) #15
length(which(cross3$Inter_or_intra == "INTER" & cross3$mated_outcome == "0")) #28
length(which(cross3$Inter_or_intra == "INTER" & cross3$mated_outcome == "1")) #2
cross3exact <- data.frame("mated" = c(15,2), "unmated" = c(15,28), row.names = c("INTRA","INTER"))
cross3exact
mosaicplot(cross3exact,color=TRUE)

#perform Fisher's exact tests
fisher.test(cross3exact,alternative="greater") 

#GLOBAL

#make compiled data frame of all crosses
assort<-rbind(cross1,cross2,cross3)

#create data frame of 2x2 contingency table
length(which(assort$Inter_or_intra == "INTRA" & assort$mated_outcome == "0")) #89
length(which(assort$Inter_or_intra == "INTRA" & assort$mated_outcome == "1")) #43
length(which(assort$Inter_or_intra == "INTER" & assort$mated_outcome == "0")) #113
length(which(assort$Inter_or_intra == "INTER" & assort$mated_outcome == "1")) #19
Globalexact <- data.frame("mated" = c(43,19), "unmated" = c(89,113), row.names = c("INTRA","INTER"))
Globalexact
mosaicplot(Globalexact,color=TRUE)

#perform Fisher's exact tests
fisher.test(Globalexact,alternative="greater") #p=0.0003784


#Post-hoc Fisher's exact tests - test for differences among 4 groups using more powerful 'fdr' method
install.packages('RVAideMemoire')
library("RVAideMemoire") # version 0.9-74

#Cross 1

#make contingency table
length(which(cross1$pair_type == "LECLEC" & cross1$mated_outcome == "0")) #n=24
length(which(cross1$pair_type == "LECLEC" & cross1$mated_outcome == "1")) #n=12
length(which(cross1$pair_type == "LECPINE" & cross1$mated_outcome == "0")) #n=36
length(which(cross1$pair_type == "LECPINE" & cross1$mated_outcome == "1")) #n=0
length(which(cross1$pair_type == "PINELEC" & cross1$mated_outcome == "0")) #n=25
length(which(cross1$pair_type == "PINELEC" & cross1$mated_outcome == "1")) #n=11
length(which(cross1$pair_type == "PINEPINE" & cross1$mated_outcome == "0")) #n=33
length(which(cross1$pair_type == "PINEPINE" & cross1$mated_outcome == "1")) #n=3
cross1exact_table <- as.table(matrix(c(12,24,0,36,11,25,3,33), ncol=4, dimnames=list(c("mated","unmated"),c("LECLEC","LECPINE","PINELEC","PINEPINE"))))
cross1exact_table
#perform exact test
fisher.multcomp(cross1exact_table)

#Cross 2

#make contingency table
length(which(cross2$pair_type == "LECLEC" & cross2$mated_outcome == "0")) #n=9
length(which(cross2$pair_type == "LECLEC" & cross2$mated_outcome == "1")) #n=6
length(which(cross2$pair_type == "LECPINE" & cross2$mated_outcome == "0")) #n=12
length(which(cross2$pair_type == "LECPINE" & cross2$mated_outcome == "1")) #n=3
length(which(cross2$pair_type == "PINELEC" & cross2$mated_outcome == "0")) #n=12
length(which(cross2$pair_type == "PINELEC" & cross2$mated_outcome == "1")) #n=3
length(which(cross2$pair_type == "PINEPINE" & cross2$mated_outcome == "0")) #n=8
length(which(cross2$pair_type == "PINEPINE" & cross2$mated_outcome == "1")) #n=7
cross2exact_table <- as.table(matrix(c(6,9,3,12,3,12,7,8), ncol=4, dimnames=list(c("mated","unmated"),c("LECLEC","LECPINE","PINELEC","PINEPINE"))))
cross2exact_table
#perform exact test
fisher.multcomp(cross2exact_table)

#Cross 3

#make contingency table
length(which(cross3$pair_type == "LECLEC" & cross3$mated_outcome == "0")) #n=5
length(which(cross3$pair_type == "LECLEC" & cross3$mated_outcome == "1")) #n=10
length(which(cross3$pair_type == "LECPINE" & cross3$mated_outcome == "0")) #n=14
length(which(cross3$pair_type == "LECPINE" & cross3$mated_outcome == "1")) #n=1
length(which(cross3$pair_type == "PINELEC" & cross3$mated_outcome == "0")) #n=14
length(which(cross3$pair_type == "PINELEC" & cross3$mated_outcome == "1")) #n=1
length(which(cross3$pair_type == "PINEPINE" & cross3$mated_outcome == "0")) #n=10
length(which(cross3$pair_type == "PINEPINE" & cross3$mated_outcome == "1")) #n=5
cross3exact_table <- as.table(matrix(c(10,5,1,14,1,14,5,10), ncol=4, dimnames=list(c("mated","unmated"),c("LECLEC","LECPINE","PINELEC","PINEPINE"))))
cross3exact_table
#perform exact test
fisher.multcomp(cross3exact_table)

#Global

#make contingency table
length(which(assort$pair_type == "LECLEC" & assort$mated_outcome == "0")) #n=38
length(which(assort$pair_type == "LECLEC" & assort$mated_outcome == "1")) #n=28
length(which(assort$pair_type == "LECPINE" & assort$mated_outcome == "0")) #n=62
length(which(assort$pair_type == "LECPINE" & assort$mated_outcome == "1")) #n=4
length(which(assort$pair_type == "PINELEC" & assort$mated_outcome == "0")) #n=51
length(which(assort$pair_type == "PINELEC" & assort$mated_outcome == "1")) #n=15
length(which(assort$pair_type == "PINEPINE" & assort$mated_outcome == "0")) #n=51
length(which(assort$pair_type == "PINEPINE" & assort$mated_outcome == "1")) #n=15
Globalexact_table <- as.table(matrix(c(28,38,4,62,15,51,15,51), ncol=4, dimnames=list(c("mated","unmated"),c("LECLEC","LECPINE","PINELEC","PINEPINE"))))
Globalexact_table
#perform exact test
fisher.multcomp(Globalexact_table)


#### Mating outcome driven primarily by pair type or size differential?

#change characters to a factor
cross1$mated_outcome<-as.factor(cross1$mated_outcome)
cross2$mated_outcome<-as.factor(cross2$mated_outcome)
cross3$mated_outcome<-as.factor(cross3$mated_outcome)
assort$mated_outcome<-as.factor(assort$mated_outcome)
assort$Experiment<-as.factor(assort$Experiment)

#by cross
#Cross 1
cross1sam<-glm(data=cross1, mated_outcome~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross1sam)
Anova(cross1sam, type=3)

#Cross 2
cross2sam<-glm(data=cross2, mated_outcome~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross2sam)
Anova(cross2sam, type=3)

#Cross 3
cross3sam<-glm(data=cross3, mated_outcome~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross3sam)
Anova(cross3sam, type=3)
plot_model(cross3sam, type="int")

#Global
globalsam<-glmer(data=assort, mated_outcome~Female_sp+Male_sp+Female_sp*Male_sp+size_differential+(1|Experiment), family=binomial)
summary(globalsam)
Anova(globalsam, type=3)
plot_model(globalsam, type="int")


#### how do males of each species differ in willingness to mate?

#change characters to a factor
cross1$attempt_made<-as.factor(cross1$attempt_made)
cross2$attempt_made<-as.factor(cross2$attempt_made)
cross3$attempt_made<-as.factor(cross3$attempt_made)
assort$attempt_made<-as.factor(assort$attempt_made)

#by cross
#Cross 1
cross1male_attempts<-glm(data=cross1, attempt_made~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross1male_attempts)
Anova(cross1male_attempts, type=3) 
plot_model(cross1male_attempts, type="int")

#Cross 2
cross2male_attempts<-glm(data=cross2, attempt_made~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross2male_attempts)
Anova(cross2male_attempts, type=3)

#Cross 3
cross3male_attempts<-glm(data=cross3, attempt_made~Female_sp*Male_sp+size_differential, family=binomial)
summary(cross3male_attempts)
Anova(cross3male_attempts, type=3) #nothing significant

#Global
Globalmale_attempts<-glmer(data=assort, attempt_made~Female_sp*Male_sp+size_differential+(1|Experiment), family=binomial)
summary(Globalmale_attempts)
Anova(Globalmale_attempts, type=3)


##### t-tests to see if interspecific vs. intraspecific pair types differ
#subset inter vs. intraspecific size differentials then do t-test

#Cross 1
cross1$Inter_or_intra<-as.factor(cross1$Inter_or_intra)
cross1intra<-subset(cross1,cross1$Inter_or_intra=="INTRA")
cross1inter<-subset(cross1,cross1$Inter_or_intra=="INTER")
t.test(cross1inter$size_differential, cross1intra$size_differential, alternative="greater")

#Cross 2
cross2$Inter_or_intra<-as.factor(cross2$Inter_or_intra)
cross2intra<-subset(cross2,cross2$Inter_or_intra=="INTRA")
cross2inter<-subset(cross2,cross2$Inter_or_intra=="INTER")
t.test(cross2inter$size_differential, cross2intra$size_differential, alternative="greater")

#Cross 3
cross3$Inter_or_intra<-as.factor(cross3$Inter_or_intra)
cross3intra<-subset(cross3,cross3$Inter_or_intra=="INTRA")
cross3inter<-subset(cross3,cross3$Inter_or_intra=="INTER")
t.test(cross3inter$size_differential, cross3intra$size_differential, alternative="greater")

#Global
assort$Inter_or_intra<-as.factor(assort$Inter_or_intra)
Globalintra<-subset(assort,assort$Inter_or_intra=="INTRA")
Globalinter<-subset(assort,assort$Inter_or_intra=="INTER")
t.test(Globalinter$size_differential, Globalintra$size_differential, alternative="greater")



####################################### FIGURES

#### FIGURE 1A: Map - all lecontei and pinetum observations to get distributions

#read in Linnen Lab/inaturalist occurrence data for both species:
occs<-read.csv(file="LinnenLab_inaturalist_observations_bySpecies.csv",header=TRUE,na.strings="NA")

#subset each species:
pineocc<-subset(occs,occs$species=="pinetum")
lecocc<-subset(occs,occs$species=="lecontei")

#read in additional museum collections
lecmus<-read.csv(file="lecontei_museum_observations.csv", header=TRUE,na.strings="NA")
pinemus<-read.csv(file="pinetum_museum_observations.csv", header=TRUE,na.strings="NA")

#rename columns to match "occs" data frame
colnames(lecmus)[1]<-"latitude"
colnames(lecmus)[2]<-"longitude"
colnames(lecmus)[3]<-"observed_on"
colnames(lecmus)[4]<-"species"
colnames(pinemus)[1]<-"latitude"
colnames(pinemus)[2]<-"longitude"
colnames(pinemus)[3]<-"observed_on"
colnames(pinemus)[4]<-"species"

#merge all occurrence data
lecall<-bind_rows(lecmus,lecocc)
pineall<-bind_rows(pinemus,pineocc)
lecall$species<-c("lecontei")
pineall$species<-c("pinetum")
alloccs<-rbind(lecall, pineall)

#make map
usa<-map_data("state")
canada<-map_data("world",region="Canada")

NAmap2<-ggplot() + geom_polygon(data=usa, aes(x=long, y=lat, group=group),fill="white",color="black") + geom_polygon(data=canada, aes(x=long, y=lat, group=group),fill="white",color="black")
NAmap2 <- NAmap2 + coord_fixed(xlim=c(-100,-50),ylim=c(25,55),ratio=1.2)
NAmap2 <- NAmap2 + geom_point(data=lecall, aes(x=longitude,y=latitude),color="red",shape=21,size=1.0)
NAmap2 <- NAmap2 + geom_point(data=pineall, aes(x=longitude,y=latitude),color="green",shape=21,size=1.0)
NAmap2 <- NAmap2 + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(line=element_blank(),text=element_blank(),rect=element_blank())
NAmap2


#### FIGURE 2 - pine needle width and adult body size clines

#Panel 2A: pine needle width cline
needle_cline<-ggplot(data=all_needles, aes(x=latitude, y=mean_needle_width, colour=host_specialist)) + geom_point() + geom_smooth(method="lm") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(axis.text.x=element_markdown(colour="black"),axis.text.y=element_markdown(colour="black"))+ scale_y_continuous(limits=c(0.25,2),expand=c(0,0)) + labs(x="Latitude",y="Average Needle Width (mm)") + scale_color_discrete(name="Host Specialist")
needle_cline_nolegend<-ggplot(data=all_needles, aes(x=latitude, y=mean_needle_width, colour=host_specialist)) + geom_point() + geom_smooth(method="lm") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(axis.text.x=element_markdown(colour="black"),axis.text.y=element_markdown(colour="black"))+ scale_y_continuous(limits=c(0.25,2),expand=c(0,0)) + labs(x="Latitude",y="Average Needle Width (mm)") + scale_color_discrete(name="Host Specialist")+ theme(legend.position="none")+ ggtitle("Host")

#Panels 2B & 2C: body size clines for females and males separately
fems_cline<-ggplot() + geom_point(data=lec_fems, aes(x=latitude, y=body_length),colour="coral2") + geom_smooth(data=lec_fems,aes(x=latitude, y=body_length), method="lm",colour="coral2")+ geom_point(data=pine_fems, aes(x=latitude, y=body_length),colour="lightseagreen") + geom_smooth(data=pine_fems,aes(x=latitude, y=body_length), method="lm",colour="lightseagreen") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(axis.text.x=element_markdown(colour="black"),axis.text.y=element_markdown(colour="black"))+ scale_y_continuous(limits=c(5,11),expand=c(0,0)) + labs(x="Latitude",y="Body length (mm)") + ggtitle("Females")
fems_cline
males_cline<-ggplot() + geom_point(data=lec_males, aes(x=latitude, y=body_length),colour="coral2") + geom_smooth(data=lec_males,aes(x=latitude, y=body_length), method="lm",colour="coral2")+ geom_point(data=pine_males, aes(x=latitude, y=body_length),colour="lightseagreen") + geom_smooth(data=pine_males,aes(x=latitude, y=body_length), method="lm",colour="lightseagreen") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(axis.text.x=element_markdown(colour="black"),axis.text.y=element_markdown(colour="black"))+ scale_y_continuous(limits=c(5,11),expand=c(0,0)) + labs(x="Latitude",y="Body length (mm)") + ggtitle("Males")
males_cline

#combine panels into 1 figure
plot_grid(needle_cline_nolegend,fems_cline,males_cline,ncol=3,nrow=1)


#### FIGURE 3: EGG DATA

#Panel 3C: differences in egg area between N. lecontei and N. pinetum
purespp_eggarea <- ggplot(data=egg_size, aes(x=Species, y=egg_area, fill=Species)) + geom_boxplot()+ theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())+ theme(legend.position="none") + scale_x_discrete(labels=c("*N. lecontei*","*N. pinetum*")) + theme(axis.text.x=element_markdown(colour="black")) + labs(y="Egg area") + theme(axis.title=element_text(size=14,colour="black"))
purespp_eggarea

#Panel 3D: effect of host and egg area on hatching success in backcross females
hatching_plot <- ggplot(data=hatch, aes(x=egg_area, y=PropHatch, colour=Host)) + geom_point(aes(colour=Host)) + geom_smooth(method="lm")
hatching_plot <- hatching_plot + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(axis.text.x=element_markdown(colour="black"))+ theme(axis.title=element_text(size=14,colour="black"))
hatching_plot <- hatching_plot + scale_colour_manual(name="Host",labels=c("jack","white"),values=c("black","red")) + scale_y_continuous(limits=c(0,1)) + scale_x_continuous(limits=c(0.45,0.58)) + labs(x="Egg area", y="Proportion of eggs hatched")
hatching_plot
#ALT - fitted logistic regression rather than lm
library(sjPlot)
plot_model(egg_hatch_model, type="int", show.data = TRUE, colors=c("#F8766D","#00BFC4"),title="")


#### FIGURE 4: prezygotic isolation (percentage of pairs that mated by pair type within each cross)

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
library(DescTools) # version 0.99.32
#Cross 1
cross1_LECLEC_prop <- BinomCI(12,36, conf.level = 0.95, method="clopper-pearson")
cross1_LECPINE_prop <- BinomCI(0,36, conf.level = 0.95, method="clopper-pearson")
cross1_PINELEC_prop <- BinomCI(11,36, conf.level = 0.95, method="clopper-pearson")
cross1_PINEPINE_prop <- BinomCI(3,36, conf.level = 0.95, method="clopper-pearson")
cross1_prop_CI <- as.data.frame(rbind(cross1_LECLEC_prop,cross1_LECPINE_prop,cross1_PINELEC_prop,cross1_PINEPINE_prop))
cross1_prop_CI$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')
cross1_prop_CI$Experiment <- c('RIE')

#Cross 2
cross2_LECLEC_prop <- BinomCI(6,15, conf.level = 0.95, method="clopper-pearson")
cross2_LECPINE_prop <- BinomCI(3,15, conf.level = 0.95, method="clopper-pearson")
cross2_PINELEC_prop <- BinomCI(3,15, conf.level = 0.95, method="clopper-pearson")
cross2_PINEPINE_prop <- BinomCI(7,15, conf.level = 0.95, method="clopper-pearson")
cross2_prop_CI <- as.data.frame(rbind(cross2_LECLEC_prop,cross2_LECPINE_prop,cross2_PINELEC_prop,cross2_PINEPINE_prop))
cross2_prop_CI$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')
cross2_prop_CI$Experiment <- c('RIB')

#Cross 3
cross3_LECLEC_prop <- BinomCI(10,15, conf.level = 0.95, method="clopper-pearson")
cross3_LECPINE_prop <- BinomCI(1,15, conf.level = 0.95, method="clopper-pearson")
cross3_PINELEC_prop <- BinomCI(1,15, conf.level = 0.95, method="clopper-pearson")
cross3_PINEPINE_prop <- BinomCI(5,15, conf.level = 0.95, method="clopper-pearson")
cross3_prop_CI <- as.data.frame(rbind(cross3_LECLEC_prop,cross3_LECPINE_prop,cross3_PINELEC_prop,cross3_PINEPINE_prop))
cross3_prop_CI$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')
cross3_prop_CI$Experiment <- c('RID')

#combine estimates for all 3 crosses
cross1_cross2_cross3_prop_CI <- as.data.frame(rbind(cross1_prop_CI,cross2_prop_CI,cross3_prop_CI))

#calculate percentages of pairs that mated/didn't mate by pair type within each cross

#Cross 1
cross1matedprops <- cross1 %>% group_by(mated_outcome,pair_type) %>% summarise(n=n(), .groups="drop_last")
cross1matedprops$total_pairs <- as.numeric(36)
cross1matedprops$percentage <- (cross1matedprops$n/cross1matedprops$total_pairs)*100
cross1matedprops$Experiment <- as.factor("RIE")
#manually add in data for missing Cross 1 LECPINE pair type: mated_outcome=1, pair_type= "LECPINE", n= 0, total_pairs=36, percentage=0, Experiment="RIE")
write.csv(cross1matedprops, file="cross1_mated_props.csv", row.names=FALSE)
cross1matedprops<-read.csv(file="cross1_mated_props.csv",header=TRUE, na.strings="NA")

#Cross 2
cross2matedprops <- cross2 %>% group_by(mated_outcome,pair_type) %>% summarise(n=n(), .groups="drop_last")
cross2matedprops$total_pairs <- as.numeric(15)
cross2matedprops$percentage <- (cross2matedprops$n/cross2matedprops$total_pairs)*100
cross2matedprops$Experiment <- as.factor("RIB")

#Cross 3
cross3matedprops <- cross3 %>% group_by(mated_outcome,pair_type) %>% summarise(n=n(), .groups="drop_last")
cross3matedprops$total_pairs <- as.numeric(15)
cross3matedprops$percentage <- (cross3matedprops$n/cross3matedprops$total_pairs)*100
cross3matedprops$Experiment <- as.factor("RID")

#combine data for all crosses 
allmatedprops <- rbind(cross1matedprops,cross2matedprops,cross3matedprops)

#only keep pairs that mated
puresppmatedperc <- subset(allmatedprops,allmatedprops$mated_outcome=="1")

#add Clopper-Pearson CI estimates to "puresppmatedperc" data frame for figure below
puresppmatedperc_new<-left_join(puresppmatedperc, cross1_cross2_cross3_prop_CI, by=c("pair_type","Experiment"))

#change CI values from proprotions to percentages
puresppmatedperc_new$upper_val <- puresppmatedperc_new$upr.ci*100
puresppmatedperc_new$lower_val <- puresppmatedperc_new$lwr.ci*100

#make plot
puresppmatedperc_new$Experiment <- factor(puresppmatedperc_new$Experiment, levels = c("RIE", "RIB", "RID"))
pairtype_labels <- c("*lecontei* \U2640 x<br>*lecontei* \U2642","*lecontei* \U2640 x<br>*pinetum* \U2642","*pinetum* \U2640 x<br>*lecontei* \U2642","*pinetum* \U2640 x<br>*pinetum* \U2642")
b1 <- ggplot(puresppmatedperc_new, aes(x=pair_type,y=percentage,fill=pair_type)) + geom_col(colour="black") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) 
b1 <- b1 + labs(x="Pair Type",y="Percentage of pairs that mated")+ facet_wrap(~Experiment, labeller=labeller(Experiment=c("RIE"="Cross 1\n RI=0.19","RIB"="Cross 2\n RI=0.37","RID"="Cross 3\n RI=0.77"))) + theme(strip.text.x=element_text(size=18,colour="black"))
b1 <- b1 + scale_y_continuous(limits=c(0,90),expand=c(0,0))
b1 <- b1 + scale_fill_grey(start=0, end=1)
b1 <- b1 + theme(legend.position="none") + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(size=14,colour="black")) + theme(axis.title=element_text(size=18,colour="black"))
b1 <- b1 + geom_errorbar( aes(x=pair_type, ymin=lower_val, ymax=upper_val), width=0.2, colour="black", alpha=0.9, size=0.75)
b1


#### FIGURE 5: SIZE-ASSORTATIVE MATING BY PAIR TYPE WITHIN EACH CROSS
#ORIGINAL
#by cross
cross_labels<-c('RIE' = "Cross 1",'RIB' = "Cross 2",'RID' = "Cross 3")
c <- ggplot(data=assort, aes(x=pair_type,y=size_differential,fill=mated_outcome)) + geom_boxplot(aes(fill=mated_outcome)) + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())
c <- c + labs(x="Pair Type",y="Size differential (mm)") + facet_wrap(~factor(Experiment,levels=c("RIE","RIB","RID")), labeller=as_labeller(cross_labels)) + theme(strip.text.x=element_text(size=20,colour="black"))
c + scale_fill_manual(name="Mating Outcome",labels=c("Did not mate","Mated"),values=c("red","goldenrod1")) + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(size=14,colour="black")) + theme(axis.title=element_text(size=20,colour="black"))
#ALT - WITH RAW DATA POINTS
c_alt<-ggplot(data=assort, aes(x=pair_type,y=size_differential,fill=mated_outcome))+ theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())+ labs(x="Pair Type",y="Size differential (mm)") + facet_wrap(~factor(Experiment,levels=c("RIE","RIB","RID")), labeller=as_labeller(cross_labels)) + theme(strip.text.x=element_text(size=20,colour="black")) + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(size=14,colour="black")) + theme(axis.title=element_text(size=20,colour="black"))+
geom_boxplot(aes(fill=mated_outcome))+ scale_fill_manual(name="Mating Outcome",labels=c("Did not mate","Mated"),values=c("red","goldenrod1")) +
  ggforce::geom_sina(
    ## draw bigger points
    size = 1.5,
    ## add some transparency
    alpha = .4,
    ## control range of the sina plot
    maxwidth = .5
  ) 
c_alt



#### FIGURE S1: MAP OF SAMPLING LOCATIONS OF ALL INDIVIDUALS MEASURED TO TEST FOR CLINAL VARIATION IN BODY LENGTH

#subset all measured individuals by species
lec_all_measured<-subset(combined_sizes, combined_sizes$species=="LECONTEI")
pine_all_measured<-subset(combined_sizes, combined_sizes$species=="PINETUM")

#make map
NAmap<-ggplot() + geom_polygon(data=usa, aes(x=long, y=lat, group=group),fill="white",color="black") + geom_polygon(data=canada, aes(x=long, y=lat, group=group),fill="white",color="black")
NAmap <- NAmap + coord_fixed(xlim=c(-100,-50),ylim=c(25,55),ratio=1.2)
NAmap <- NAmap + geom_point(data=lec_all_measured, aes(x=longitude,y=latitude),fill="coral2",shape=21,size=3.0)
NAmap <- NAmap + geom_point(data=pine_all_measured, aes(x=longitude,y=latitude),fill="lightseagreen",shape=21,size=3.0)
NAmap <- NAmap + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(line=element_blank(),text=element_blank(),rect=element_blank())
NAmap


#### FIGURE S4: GLOBAL PREZYGOTIC ISOLATION (PERCENTAGE OF PAIRS THAT MATED BY PAIR TYPE)

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
Global_LECLEC_prop <- BinomCI(28,66, conf.level = 0.95, method="clopper-pearson")
Global_LECPINE_prop <- BinomCI(4,66, conf.level = 0.95, method="clopper-pearson")
Global_PINELEC_prop <- BinomCI(15,66, conf.level = 0.95, method="clopper-pearson")
Global_PINEPINE_prop <- BinomCI(15,66, conf.level = 0.95, method="clopper-pearson")
Global_prop_CI <- as.data.frame(rbind(Global_LECLEC_prop,Global_LECPINE_prop,Global_PINELEC_prop,Global_PINEPINE_prop))
Global_prop_CI$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')

#calculate percentage of pairs that mated for each pair type
globalmatedprops <- assort %>% group_by(mated_outcome,pair_type) %>% summarise(n=n(), .groups="drop_last")
globalmatedprops$total_pairs <- as.numeric(66)
globalmatedprops$percentage <- (globalmatedprops$n/globalmatedprops$total_pairs)*100
globalmatedperc <- subset(globalmatedprops, globalmatedprops$mated_outcome=="1")

#add estimates to "globalmatedperc" data frame for figure below
globalmatedperc<-left_join(globalmatedperc, Global_prop_CI, by=c("pair_type"))
globalmatedperc$upper_val <- globalmatedperc$upr.ci*100
globalmatedperc$lower_val <- globalmatedperc$lwr.ci*100

#make plot
b2 <- ggplot(globalmatedperc, aes(x=pair_type,y=percentage,fill=pair_type)) + geom_col(colour="black") + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())
b2 <- b2 + labs(x="Pair Type",y="Percentage of pairs that mated") + theme(strip.text.x=element_text(size=11,colour="black"))
b2 <- b2 + scale_y_continuous(limits=c(0,70),expand=c(0,0))
b2 <- b2 + scale_fill_grey(start=0, end=1)
b2 <- b2 + theme(legend.position="none") + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(colour="black")) +ggtitle("Global \n RI=0.39") + theme(plot.title = element_text(hjust = 0.5))
b2 <- b2 + geom_errorbar( aes(x=pair_type, ymin=lower_val, ymax=upper_val), width=0.2, colour="black", alpha=0.9, size=0.75)
b2


#### FIGURE S5: GLOBAL SIZE-ASSORTATIVE MATING
c2 <- ggplot(data=assort, aes(x=pair_type,y=size_differential,fill=mated_outcome)) + geom_boxplot(aes(fill=mated_outcome)) + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())
c2 <- c2 + labs(x="Pair Type",y="Size differential (mm)")  + theme(strip.text.x=element_text(size=11,colour="black"))
c2 + scale_fill_manual(name="Mating Outcome",labels=c("Did not mate","Mated"),values=c("red","goldenrod1")) + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(colour="black")) + ggtitle("Global")



#### FIGURE S6: LOGISTIC REGRESSION PLOTS OF MATING OUTCOME VS. SIZE DIFFERENTIAL FOR ALL PAIR TYPES COMBINED
#Cross 1
h1 <- plot_model(cross1sam, type="pred",show.data=TRUE, title="",terms="size_differential [all]")
#Cross 2
h2 <- plot_model(cross2sam, type="pred",show.data=TRUE, title="",terms="size_differential [all]")
#Cross 3
h3 <- plot_model(cross3sam, type="pred",show.data=TRUE, title="",terms="size_differential [all]")
#Global
plot_model(globalsam, type="pred",show.data=TRUE, title="",terms="size_differential [all]")
#combine plots
plot_grid(h1,h2,h3,ncol=2,nrow=2)

#### FIGURE S7: VARIATION IN MALE WILLINGNESS/MOTIVATION TO MATE BY CROSS AND GLOBALLY

#by cross

#Cross 1
cross1attemptedprops <- cross1 %>% group_by(attempt_made,pair_type) %>% summarise(n=n(), .groups="drop_last") #3 PINELEC & 3 PINEPINE pairs NA
cross1attemptedprops <- na.omit(cross1attemptedprops)
cross1attemptedprops$total_pairs <- as.numeric(36)

#change PINELEC and PINEPINE total pairs to 33
cross1attemptedprops[3, 4] = 33
cross1attemptedprops[4, 4] = 33
cross1attemptedprops[7, 4] = 33
cross1attemptedprops[8, 4] = 33
cross1attemptedprops$percentage <- (cross1attemptedprops$n/cross1attemptedprops$total_pairs)*100
cross1attemptedprops$Experiment <- as.factor("RIE")

#only keep pairs where an attempt was made
cross1attemptedperc <- subset(cross1attemptedprops, cross1attemptedprops$attempt_made=="1")

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
cross1_LECLEC_prop_attempt <- BinomCI(19,36, conf.level = 0.95, method="clopper-pearson")
cross1_LECPINE_prop_attempt <- BinomCI(5,36, conf.level = 0.95, method="clopper-pearson")
cross1_PINELEC_prop_attempt <- BinomCI(17,33, conf.level = 0.95, method="clopper-pearson")
cross1_PINEPINE_prop_attempt <- BinomCI(8,33, conf.level = 0.95, method="clopper-pearson")
cross1_prop_CI_attempt <- as.data.frame(rbind(cross1_LECLEC_prop_attempt,cross1_LECPINE_prop_attempt,cross1_PINELEC_prop_attempt,cross1_PINEPINE_prop_attempt))
cross1_prop_CI_attempt$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')

#combine attempt data and CI data
cross1_attempt_CI<-left_join(cross1attemptedperc, cross1_prop_CI_attempt, by=c("pair_type"))

#Cross 2
cross2attemptedprops <- cross2 %>% group_by(attempt_made,pair_type) %>% summarise(n=n(), .groups="drop_last")
cross2attemptedprops <- na.omit(cross2attemptedprops) #12 pairs were omitted (video problems) so 48 pairs total
cross2attemptedprops$total_pairs <- as.numeric(12)
cross2attemptedprops$percentage <- (cross2attemptedprops$n/cross2attemptedprops$total_pairs)*100
cross2attemptedprops$Experiment <- as.factor("RIB")

#only keep pairs where an attempt was made
cross2attemptedperc <- subset(cross2attemptedprops, cross2attemptedprops$attempt_made=="1")

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
cross2_LECLEC_prop_attempt <- BinomCI(9,12, conf.level = 0.95, method="clopper-pearson")
cross2_LECPINE_prop_attempt <- BinomCI(6,12, conf.level = 0.95, method="clopper-pearson")
cross2_PINELEC_prop_attempt <- BinomCI(11,12, conf.level = 0.95, method="clopper-pearson")
cross2_PINEPINE_prop_attempt <- BinomCI(9,12, conf.level = 0.95, method="clopper-pearson")
cross2_prop_CI_attempt <- as.data.frame(rbind(cross2_LECLEC_prop_attempt,cross2_LECPINE_prop_attempt,cross2_PINELEC_prop_attempt,cross2_PINEPINE_prop_attempt))
cross2_prop_CI_attempt$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')

#combine attempt data and CI data
cross2_attempt_CI<-left_join(cross2attemptedperc, cross2_prop_CI_attempt, by=c("pair_type"))

#Cross 3
cross3attemptedprops <- cross3 %>% group_by(attempt_made,pair_type) %>% summarise(n=n(), .groups="drop_last") #3 LECLEC & 3 LECPINE pairs NA
cross3attemptedprops <- na.omit(cross3attemptedprops) 
cross3attemptedprops$total_pairs <- as.numeric(15)

#change LECLEC and LECPINE total pairs to 12
cross3attemptedprops[1, 4] = 12
cross3attemptedprops[2, 4] = 12
cross3attemptedprops[5, 4] = 12
cross3attemptedprops[6, 4] = 12
cross3attemptedprops$percentage <- (cross3attemptedprops$n/cross3attemptedprops$total_pairs)*100
cross3attemptedprops$Experiment <- as.factor("RID")

#only keep pairs where an attempt was made
cross3attemptedperc <- subset(cross3attemptedprops, cross3attemptedprops$attempt_made=="1")

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
cross3_LECLEC_prop_attempt <- BinomCI(9,12, conf.level = 0.95, method="clopper-pearson")
cross3_LECPINE_prop_attempt <- BinomCI(4,12, conf.level = 0.95, method="clopper-pearson")
cross3_PINELEC_prop_attempt <- BinomCI(9,15, conf.level = 0.95, method="clopper-pearson")
cross3_PINEPINE_prop_attempt <- BinomCI(11,15, conf.level = 0.95, method="clopper-pearson")
cross3_prop_CI_attempt <- as.data.frame(rbind(cross3_LECLEC_prop_attempt,cross3_LECPINE_prop_attempt,cross3_PINELEC_prop_attempt,cross3_PINEPINE_prop_attempt))
cross3_prop_CI_attempt$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')

#combine attempt data and CI data
cross3_attempt_CI<-left_join(cross3attemptedperc, cross3_prop_CI_attempt, by=c("pair_type"))

#combine crosses to plot together
allattemptedperc <- rbind(cross1_attempt_CI,cross2_attempt_CI,cross3_attempt_CI)
allattemptedperc$fem_sp <- as.factor(c("lecontei","lecontei", "pinetum", "pinetum", "lecontei", "lecontei", "pinetum", "pinetum", "lecontei", "lecontei", "pinetum", "pinetum"))
allattemptedperc$male_sp <- as.factor(c("lecontei","pinetum", "lecontei", "pinetum", "lecontei", "pinetum", "lecontei", "pinetum", "lecontei", "pinetum", "lecontei", "pinetum"))

#make plot
allattemptedperc$Experiment <- factor(allattemptedperc$Experiment, levels = c("RIE", "RIB", "RID"))
allattemptedperc$upper_val <- allattemptedperc$upr.ci*100
allattemptedperc$lower_val <- allattemptedperc$lwr.ci*100
e1 <- ggplot(allattemptedperc, aes(x=male_sp,y=percentage,fill=fem_sp)) + geom_col(colour="black",position="dodge") + geom_errorbar( aes(x=male_sp, ymin=lower_val, ymax=upper_val), width=0.2, colour="black", alpha=0.9, size=0.75, position=position_dodge(.9))
e1 <- e1 + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) 
e1 <- e1 + labs(x="Male species",y="Percentage of pairs with male attempt made")+ facet_wrap(~Experiment, labeller=labeller(Experiment=c("RIE"="Cross 1","RIB"="Cross 2","RID"="Cross 3"))) + theme(strip.text.x=element_text(size=18,colour="black"))
e1 <- e1 + scale_y_continuous(limits=c(0,100),expand=c(0,0))
e1 <- e1 + scale_fill_grey(start=0, end=1,name="Female species",labels=c("N. lecontei","N. pinetum"))
e1

#Global
globalattemptedprops <- assort %>% group_by(attempt_made,pair_type) %>% summarise(n=n(), .groups="drop_last") #6 pairs of each pair type are NAs
globalattemptedprops <- na.omit(globalattemptedprops)
globalattemptedprops$total_pairs <- as.numeric(60)
globalattemptedprops$percentage <- (globalattemptedprops$n/globalattemptedprops$total_pairs)*100

#only keep pairs where an attempt was made
globalattemptedperc <- subset(globalattemptedprops, globalattemptedprops$attempt_made=="1")

# Obtain Clopper-Pearson 95% confidence intervals for proportion (a conservative method) 
Global_LECLEC_prop_attempt <- BinomCI(37,60, conf.level = 0.95, method="clopper-pearson")
Global_LECPINE_prop_attempt <- BinomCI(15,60, conf.level = 0.95, method="clopper-pearson")
Global_PINELEC_prop_attempt <- BinomCI(37,60, conf.level = 0.95, method="clopper-pearson")
Global_PINEPINE_prop_attempt <- BinomCI(28,60, conf.level = 0.95, method="clopper-pearson")
Global_prop_CI_attempt <- as.data.frame(rbind(Global_LECLEC_prop_attempt,Global_LECPINE_prop_attempt,Global_PINELEC_prop_attempt,Global_PINEPINE_prop_attempt))
Global_prop_CI_attempt$pair_type <- c('LECLEC', 'LECPINE', 'PINELEC', 'PINEPINE')

#combine attempt data and CI data
global_attempt_CI<-left_join(globalattemptedperc, Global_prop_CI_attempt, by=c("pair_type"))
global_attempt_CI$fem_sp <- as.factor(c("lecontei","lecontei","pinetum","pinetum"))
global_attempt_CI$male_sp <- as.factor(c("lecontei","pinetum","lecontei","pinetum"))

#make plot
global_attempt_CI$upper_val <- global_attempt_CI$upr.ci*100
global_attempt_CI$lower_val <- global_attempt_CI$lwr.ci*100
e2 <- ggplot(global_attempt_CI, aes(x=male_sp,y=percentage,fill=fem_sp)) + geom_col(colour="black",position="dodge") + geom_errorbar( aes(x=male_sp, ymin=lower_val, ymax=upper_val), width=0.2, colour="black", alpha=0.9, size=0.75, position=position_dodge(.9))
e2 <- e2 + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) 
e2 <- e2 + labs(x="Male species",y="Percentage of pairs with male attempt made") + ggtitle("Global")
e2 <- e2 + scale_y_continuous(limits=c(0,100),expand=c(0,0))
e2 <- e2 + scale_fill_grey(start=0, end=1,name="Female species",labels=c("N. lecontei","N. pinetum"))
e2



#### FIGURE S8: male attempts influenced by size differentials?
assort$attempt_made<-as.factor(assort$attempt_made)
#by cross
f <- ggplot(data=subset(assort, !is.na(attempt_made)), aes(x=pair_type,y=size_differential,fill=attempt_made)) + geom_boxplot(aes(fill=attempt_made)) + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())
f <- f + labs(x="Pair Type",y="Size differential (mm)") + facet_wrap(~factor(Experiment,levels=c("RIE","RIB","RID")), labeller=as_labeller(cross_labels)) + theme(strip.text.x=element_text(size=20,colour="black"))
f + scale_fill_manual(name="Attempt made",labels=c("No","Yes"),values=c("red","goldenrod1")) + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(size=14,colour="black")) + theme(axis.title=element_text(size=20,colour="black"))
#global
f2 <- ggplot(data=subset(assort, !is.na(attempt_made)), aes(x=pair_type,y=size_differential,fill=attempt_made)) + geom_boxplot(aes(fill=attempt_made)) + theme_light() + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank())
f2 <- f2 + labs(x="Pair Type",y="Size differential (mm)")  + theme(strip.text.x=element_text(size=11,colour="black"))
f2 + scale_fill_manual(name="Attempt made",labels=c("No","Yes"),values=c("red","goldenrod1")) + scale_x_discrete(labels=pairtype_labels) + theme(axis.text.x=element_markdown(colour="black")) + ggtitle("Global")



#### FIGURE S9: SAM CONTRIBUTES TO RI (INTER VS. INTRA)

#create new data frame and change experiment codes ("RIB",etc.) to "Cross X"
assort1 <- assort
library('stringr')
assort1$Experiment <- str_replace(assort1$Experiment, 'RIB', 'Cross 2')
assort1$Experiment <- str_replace(assort1$Experiment, 'RID', 'Cross 3')
assort1$Experiment <- str_replace(assort1$Experiment, 'RIE', 'Cross 1')
assort1$Experiment<-as.factor(assort1$Experiment)

#make plots
inter_labels <- c("Interspecific", "Intraspecific")

#by cross
library(ggforce)
library(ggpval)
#By cross
g<-ggplot(assort1, aes(x = Inter_or_intra, y = size_differential,fill=Inter_or_intra))+facet_wrap(~Experiment, labeller=labeller(Experiment=c("Cross 1"="Cross 1\n RI=0.19","Cross 2"="Cross 2\n RI=0.37","Cross 3"="Cross 3\n RI=0.77")))+ theme_light()+ labs(x="Pair type",y="Size differential (mm)") + scale_x_discrete(labels=inter_labels) + theme(legend.position="none") + scale_fill_manual(values=c("darkviolet","burlywood2"))+ theme(axis.text.x=element_markdown(colour="black")) + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(strip.text.x=element_text(size=11,colour="black")) + 
  geom_boxplot() +
  ggforce::geom_sina(
    ## draw bigger points
    size = 1.5,
    ## add some transparency
    alpha = .4,
    ## control range of the sina plot
    maxwidth = .5
  ) 
g
add_pval(g, test='t.test', alternative="greater",textsize=10)

#global
g2<-ggplot(assort, aes(x = Inter_or_intra, y = size_differential,fill=Inter_or_intra))+ theme_light()+ labs(x="Pair type",y="Size differential (mm)") + scale_x_discrete(labels=inter_labels) + theme(legend.position="none") + scale_fill_manual(values=c("darkviolet","burlywood2"))+ theme(axis.text.x=element_markdown(colour="black")) + theme(panel.grid.major.x=element_blank(),panel.grid.minor.x=element_blank()) + theme(strip.text.x=element_text(size=11,colour="black"))+ggtitle("Global \n RI=0.39") + theme(plot.title = element_text(hjust = 0.5)) + 
  geom_boxplot() +
  ggforce::geom_sina(
    ## draw bigger points
    size = 1.5,
    ## add some transparency
    alpha = .4,
    ## control range of the sina plot
    maxwidth = .5
  ) 
g2
add_pval(g2, test='t.test', alternative="greater")















